Lignes d'azur : le Réseau de Transport de Nice Côte d'Azur - Horaires

Vous êtes à l'arrêt
INRIA
Horaires
Date : 14/12/2016
Il est 16h49 Actualiser
Ligne : 230
dans 9 min direction Cathédrale-Vieille Ville
dans 12 min direction Gambetta / France
à 17h12 direction Cathédrale-Vieille Ville
à 17h22 direction Cathédrale-Vieille Ville *
à 17h32 direction Cathédrale-Vieille Ville *
à 17h37 direction Gambetta / France *
à 17h42 direction Cathédrale-Vieille Ville *
Ligne : 233
à 17h28 direction Halte Routière de l'Ara *
Ligne : 232
à 17h33 direction Carros Médiathèque *
* horaires théoriques